@@ -220,7 +220,17 @@ class BuildContext(collections.namedtuple('_BuildContext',
             kind='build')
         logger.info("build successful, copying artifacts")
         dist_base = os.path.join(self.testbed_dist, VSRC_DIR)
-        testbed.check_exec2(shell_copy_pattern(dist_base, self.testbed_src, artifact_pattern))
+        try:
+            testbed.check_exec2(shell_copy_pattern(dist_base, self.testbed_src, artifact_pattern))
+        except:
+            # workaround when build_path.path is not the defaults
+            os.makedirs(build.tree, exist_ok=True)
+            testbed.check_exec2(shell_copy_pattern(dist_base, build.tree, artifact_pattern))
+            # clean up artifacts and build directory
+            testbed.check_exec2(['sh', '-ec', 'cd "%s" && rm -rvf %s' %
+                                 (build.tree, artifact_pattern)])
+            testbed.check_exec2(['sh', '-ec', 'rmdir -v %s' % build.tree])
+
         # FIXME: `touch` is needed because of the FIXME in build.faketime(). we can rm it after that is fixed
         testbed.check_exec2(['sh', '-ec',
             r"""cd "{0}" && touch -d@0 . .. {1}""".format(dist_base, artifact_pattern)])
@@ -347,7 +357,7 @@ class TestArgs(collections.namedtuple('_Test',
         print("Reproduction successful")
         print("=======================")
         print("No differences in %s" % self.artifact_pattern, flush=True)
-        run_or_tee(['sh', '-ec', 'find %s -type f -exec sha256sum "{}" \;' % self.artifact_pattern],
+        run_or_tee(['sh', '-ec', 'find %s -type f -exec sha256sum "{}" \\;' % self.artifact_pattern],
             'SHA256SUMS', self.result_dir,
             cwd=os.path.join(dist_control, VSRC_DIR))
 
